@@ -3,7 +3,7 @@ use warnings;
 
 package Net::Amazon::Route53::Change;
 BEGIN {
-  $Net::Amazon::Route53::Change::VERSION = '0.110090';
+  $Net::Amazon::Route53::Change::VERSION = '0.110240';
 }
 use Mouse;
 
@@ -60,11 +60,11 @@ Refresh the details of the change. When performed, the object's status is curren
 
 =cut
 
-sub refresh
-{
+sub refresh {
     my $self = shift;
     die "Cannot refresh without an id\n" unless length $self->id;
-    my $resp = $self->route53->request( 'get', 'https://route53.amazonaws.com/2010-10-01/' . $self->id, );
+    my $resp =
+      $self->route53->request( 'get', 'https://route53.amazonaws.com/2010-10-01/' . $self->id, );
     for (qw/Id Status SubmittedAt/) {
         my $method = lc $_;
         $self->$method( $resp->{ChangeInfo}{$_} );
